aboutsummaryrefslogtreecommitdiff
path: root/ef-day-theme.el
diff options
context:
space:
mode:
authorProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
committerProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
commitc11d7b767134be9a7b91453e2792fe009c7529b7 (patch)
tree85207f0378436a6cbec1c52087acdca500418e88 /ef-day-theme.el
parent0416ea8554a78e8ae352fb314a336672b048d41c (diff)
Make theme one-line descriptions more descriptive
Diffstat (limited to 'ef-day-theme.el')
-rw-r--r--ef-day-theme.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/ef-day-theme.el b/ef-day-theme.el
index 7d0a4ab..6d197bc 100644
--- a/ef-day-theme.el
+++ b/ef-day-theme.el
@@ -1,4 +1,4 @@
;;; ef-day-theme.el --- Legible light theme with warm colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-day "Legible light theme with warm colors.")
+ (deftheme ef-day "Legible light theme with warm, varied colors (yellow, red, green, purple).")
(defconst ef-day-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-day-theme.el --- Legible light theme with warm colors -*- lexical-binding:t -*-
+;;; ef-day-theme.el --- Legible light theme with warm, varied colors (yellow, red, green, purple) -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.